diff --git a/books/bookvolbib.pamphlet b/books/bookvolbib.pamphlet
index 2b24ac7..602047a 100644
--- a/books/bookvolbib.pamphlet
+++ b/books/bookvolbib.pamphlet
@@ -3201,5 +3201,29 @@ Greve, David A.; McClurg, Jedidiah R.\\
 in Lecture Notes in Computer Science, Springer ISBN 978-3-540-85520-0
 (2006) pp102-113
 
+\subsection{Numeric Tests} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+\bibitem[Lef\'evre 06]{Lef06} Lef\'evre, Vincent; Stehl\'e, Damien;
+Zimmermann, Paul\\
+``Worst Cases for the Exponential Function 
+in the IEEE-754r decimal64 Format''\\
+in Lecture Notes in Computer Science, Springer ISBN 978-3-540-85520-0
+(2006) pp114-125
+
+\begin{adjustwidth}{2.5em}{0pt}
+We searched for the worst cases for correct rounding of the 
+exponential function in the IEEE 754r decimal64 format, and computed
+all the bad cases whose distance from a breakpoint (for all rounding 
+modes) is less than $10^{-15}$ ulp, and we give the worst ones. In
+particular, the worst case for 
+$\vert{}x\vert{} \ge 3 x 10^{-11}$ is
+\[
+exp(9.407822313572878x10^{-2} = 1.09864568206633850000000000000000278\ldots
+\]
+This work can be extended to other elementary functions in the decimal64
+format and allows the design of reasonably fast routines that will
+evaluate these functions with correct rounding, at least in some situations.
+\end{adjustwidth}
+
 \end{thebibliography}
 \end{document}
diff --git a/changelog b/changelog
index 263703c..0ddadf3 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,7 @@
+20140618 tpd src/axiom-website/patches.html 20140618.01.tpd.patch
+20140618 tpd src/input/Makefile add src/input/exptest.input
+20140618 tpd src/input/exptest.input test worst case exponential values
+20140618 tpd books/bookvolbib add Lef06
 20140617 tpd src/axiom-website/patches.html 20140617.01.tpd.patch
 20140617 tpd books/bookvol10.1 add interval arithmetic
 20140617 tpd books/bookvolbib add interval arithmetic
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index b76c633..0cf65d4 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4476,6 +4476,8 @@ buglist wish 1011: sum(1/(k+a), k=1..n) by Gosper's method
 src/input/polygamma.input add a polygamma example
 <a href="patches/20140617.01.tpd.patch">20140617.01.tpd.patch</a>
 books/bookvol10.1, bookvolbib add interval arithmetic
+<a href="patches/20140618.01.tpd.patch">20140618.01.tpd.patch</a>
+src/input/exptest.input test worst case exponential values
  </body>
 </html>
 
diff --git a/src/input/Makefile.pamphlet b/src/input/Makefile.pamphlet
index 394ffd6..a26026c 100644
--- a/src/input/Makefile.pamphlet
+++ b/src/input/Makefile.pamphlet
@@ -328,7 +328,7 @@ REGRESSTESTS= ackermann.regress \
     evalex.regress   eval.regress     exdiff.regress \
     exampleagcode.regress \
     exint.regress     exit.regress     exlap.regress    exlimit.regress \
-    exp.regress \
+    exp.regress       exptest.regress \
     expexpan.regress  explim.regress   expr1.regress    exprode.regress \
     expr.regress      exseries.regress exsum.regress    exprpoly.regress \
     farray.regress    ffdemo.regress   fferr.regress    ffieldbug.regress \
@@ -740,8 +740,8 @@ FILES= ${OUT}/ackermann.input \
        ${OUT}/elt.input      ${OUT}/en.input \
        ${OUT}/eq.input       ${OUT}/eqtbl.input      ${OUT}/equation.input \
        ${OUT}/errortrap.input \
-       ${OUT}/eval.input     ${OUT}/exit.input       ${OUT}/exp.input \
-       ${OUT}/expexpan.input \
+       ${OUT}/eval.input     ${OUT}/exit.input       ${OUT}/exptest.input \
+       ${OUT}/exp.input      ${OUT}/expexpan.input \
        ${OUT}/explim.input   ${OUT}/explot2d.input   ${OUT}/explot3d.input \
        ${OUT}/expr1.input    ${OUT}/exprpoly.input \
        ${OUT}/farray.input   ${OUT}/ffdemo.input \
@@ -1125,7 +1125,7 @@ DOCFILES= \
   ${DOC}/exampleagcode.input.dvi \
   ${DOC}/exint.input.dvi       ${DOC}/exit.input.dvi       \
   ${DOC}/exlap.input.dvi       ${DOC}/exlimit.input.dvi    \
-  ${DOC}/exp.input.dvi         \
+  ${DOC}/exp.input.dvi         ${DOC}/exptest.input.dvi    \
   ${DOC}/expexpan.input.dvi    ${DOC}/explim.input.dvi     \
   ${DOC}/explot2d.input.dvi    ${DOC}/explot3d.input.dvi   \
   ${DOC}/expr1.input.dvi       ${DOC}/expr.input.dvi       \
diff --git a/src/input/exptest.input.pamphlet b/src/input/exptest.input.pamphlet
new file mode 100644
index 0000000..7273a18
--- /dev/null
+++ b/src/input/exptest.input.pamphlet
@@ -0,0 +1,2387 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input exptest.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+Worst Cases for the Exponential Function in the IEEE-754r decimal64 Format
+
+by Vincent Lef\'evre, Damien Stehl\'e, Paul Zimmermann
+
+We searched for the worst cases for correct rounding of the 
+exponential function in the IEEE 754r decimal64 format, and computed
+all the bad cases whose distance from a breakpoint (for all rounding 
+modes) is less than $10^{-15}$ ulp, and we give the worst ones. In
+particular, the worst case for 
+$\vert{}x\vert{} \ge 3 x 10^{-11}$ is
+\[
+exp(9.407822313572878x10^{-2} = 1.09864568206633850000000000000000278\ldots
+\]
+This work can be extended to other elementary functions in the decimal64
+format and allows the design of reasonably fast routines that will
+evaluate these functions with correct rounding, at least in some situations.
+
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f exptest.output
+)spool exptest.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 288
+digits(50)
+--R 
+--R
+--R   (1)  20
+--R                                                        Type: PositiveInteger
+--E 1
+
+--S 2 of 288
+t1:=exp(9.407822313572878E-2)
+--R 
+--R
+--R   (2)  1.0986456820 6633850000 0000000000 0027805367 999050547
+--R                                                                  Type: Float
+--E 2
+
+--S 3 of 288
+t1-1.09864568206633850000000000000000278
+--R 
+--R
+--R   (3)  0.5367999050 547 E -36
+--R                                                                  Type: Float
+--E 3
+
+--S 4 of 288
+t2:=exp(9.999999999999995E-16)
+--R 
+--R
+--R   (4)  1.0000000000 0000099999 9999999999 9999999999 999996667
+--R                                                                  Type: Float
+--E 4
+
+--S 5 of 288
+t2-1.000000000000000999999999999999999999999999999666
+--R 
+--R
+--R   (5)  0.7 E -48
+--R                                                                  Type: Float
+--E 5
+
+--S 6 of 288
+t3:=exp(0.5091077534282133)
+--R 
+--R
+--R   (6)  1.6638060072 6150950000 0000000000 0492443217 490289874
+--R                                                                  Type: Float
+--E 6
+
+--S 7 of 288
+t3-1.663806007261509500000000000000049
+--R 
+--R
+--R   (7)  0.2443217490 289874 E -33
+--R                                                                  Type: Float
+--E 7
+
+--S 8 of 288
+t4:=exp(0.7906867968553504)
+--R 
+--R
+--R   (8)  2.2049102317 7150949999 9999999999 9163630300 32777977
+--R                                                                  Type: Float
+--E 8
+
+--S 9 of 288
+t4-2.204910231771509499999999999999916
+--R 
+--R
+--R   (9)  0.3630300327 77977 E -33
+--R                                                                  Type: Float
+--E 9
+
+--S 10 of 288
+t5:=exp(0.001548443067391468)
+--R 
+--R
+--R   (10)  1.0015496425 2437499999 9999999999 9265764835 714768111
+--R                                                                  Type: Float
+--E 10
+
+--S 11 of 288
+t5-1.001549642524374999999999999999926
+--R 
+--R
+--R   (11)  0.5764835714 768111 E -33
+--R                                                                  Type: Float
+--E 11
+
+--S 12 of 288
+t6:=exp(0.2953379504777270)
+--R 
+--R
+--R   (12)  1.3435803455 8906700000 0000000000 0864880085 307257641
+--R                                                                  Type: Float
+--E 12
+
+--S 13 of 288
+t6-1.343580345589067000000000000000086
+--R 
+--R
+--R   (13)  0.4880085307 257641 E -33
+--R                                                                  Type: Float
+--E 13
+
+--S 14 of 288
+t7:=log(10.E385-10.E369/2)
+--R 
+--R
+--R   (14)  888.7978458957 0163398094 4701508164 5828840251 7461071
+--R                                                                  Type: Float
+--E 14
+
+--S 15 of 288
+t7-886.4952608027075882469
+--R 
+--R
+--R   (15)  2.3025850929 9404573404 4701508164 5828840251 746107
+--R                                                                  Type: Float
+--E 15
+
+--S 16 of 288
+t8:=log(10.E-398/2)
+--R 
+--R
+--R   (16)  - 914.8194290991 9608186455 9839631150 7669857127 9111998
+--R                                                                  Type: Float
+--E 16
+
+--S 17 of 288
+t8-(-917.12201419219012)
+--R 
+--R
+--R   (17)  2.3025850929 9403813544 0160368849 2330142872 0888
+--R                                                                  Type: Float
+--E 17
+
+--S 18 of 288
+t9:=log(1.0-10.0E-16/2)
+--R 
+--R
+--R   (18)  - 0.5000000000 0000012500 0000000000 0416679603 9339282205 E -15
+--R                                                                  Type: Float
+--E 18
+
+--S 19 of 288
+t9-(-5.000000000000000127E-17)
+--R 
+--R
+--R   (19)  - 0.4500000000 0000012373 0000000000 0416679603 9339282204 E -15
+--R                                                                  Type: Float
+--E 19
+
+--S 20 of 288
+t10:=log(1.0+10.E-15/2)
+--R 
+--R
+--R   (20)  0.4999999999 9999875000 0000000004 1666668912 8749314454 E -14
+--R                                                                  Type: Float
+--E 20
+
+--S 21 of 288
+t10-4.999999999999999750E-16
+--R 
+--R
+--R   (21)  0.4499999999 9999875250 0000000004 1666668912 8749314454 E -14
+--R                                                                  Type: Float
+--E 21
+
+\end{chunk}
+
+Table 2 has all worst cases of the decimal64 exponential function for
+$x \ge 10^{-9}$, whose distance from a breakpoint is less than
+$5 x 10^{-17}$ ulp. The notation $d^k$ means that the digit $d$
+is repeated $k$ times.
+
+\begin{chunk}{*}
+
+--S 22 of 288
+table2ax:=6.581539478341669E-9
+--R 
+--R
+--R   (22)  0.6581539478 341669 E -8
+--R                                                                  Type: Float
+--E 22
+
+--S 23 of 288
+t2a:=exp(table2ax)
+--R 
+--R
+--R   (23)  1.0000000065 8153950000 0000000000 0177317374 05802621
+--R                                                                  Type: Float
+--E 23
+
+--S 24 of 288
+table2ay:=1.0000000065815395000000000000000177
+--R 
+--R
+--R   (24)  1.0000000065 8153950000 0000000000 0177
+--R                                                                  Type: Float
+--E 24
+
+--S 25 of 288
+t2a-table2ay
+--R 
+--R
+--R   (25)  0.3173740580 2621 E -34
+--R                                                                  Type: Float
+--E 25
+
+--S 26 of 288
+table2bx:=2.662858264545929E-8
+--R 
+--R
+--R   (26)  0.2662858264 545929 E -7
+--R                                                                  Type: Float
+--E 26
+
+--S 27 of 288
+t2b:=exp(table2bx)
+--R 
+--R
+--R   (27)  1.0000000266 2858300000 0000000000 0318906153 379112945
+--R                                                                  Type: Float
+--E 27
+
+--S 28 of 288
+table2by:=1.0000000266285830000000000000000318
+--R 
+--R
+--R   (28)  1.0000000266 2858300000 0000000000 0318
+--R                                                                  Type: Float
+--E 28
+
+--S 29 of 288
+t2b-table2by
+--R 
+--R
+--R   (29)  0.9061533791 12945 E -34
+--R                                                                  Type: Float
+--E 29
+
+--S 30 of 288
+table2cx:=3.639588333766983E-8
+--R 
+--R
+--R   (30)  0.3639588333 766983 E -7
+--R                                                                  Type: Float
+--E 30
+
+--S 31 of 288
+t2c:=exp(table2cx)
+--R 
+--R
+--R   (31)  1.0000000363 9588400000 0000000000 0240621754 275940933
+--R                                                                  Type: Float
+--E 31
+
+--S 32 of 288
+table2cy:=1.0000000363958840000000000000000240
+--R 
+--R
+--R   (32)  1.0000000363 9588400000 0000000000 024
+--R                                                                  Type: Float
+--E 32
+
+--S 33 of 288
+t2c-table2cy
+--R 
+--R
+--R   (33)  0.6217542759 40933 E -34
+--R                                                                  Type: Float
+--E 33
+
+--S 34 of 288
+table2dx:=6.036998017773271E-8
+--R 
+--R
+--R   (34)  0.6036998017 773271 E -7
+--R                                                                  Type: Float
+--E 34
+
+--S 35 of 288
+t2d:=exp(table2dx)
+--R 
+--R
+--R   (35)  1.0000000603 6998200000 0000000000 0379694922 010746078
+--R                                                                  Type: Float
+--E 35
+
+--S 36 of 288
+table2dy:=1.0000000603699820000000000000000379
+--R 
+--R
+--R   (36)  1.0000000603 6998200000 0000000000 0379
+--R                                                                  Type: Float
+--E 36
+
+--S 37 of 288
+t2d-table2dy
+--R 
+--R
+--R   (37)  0.6949220107 46078 E -34
+--R                                                                  Type: Float
+--E 37
+
+--S 38 of 288
+table2ex:=6.638670361402304E-7
+--R 
+--R
+--R   (38)  0.6638670361 402304 E -6
+--R                                                                  Type: Float
+--E 38
+
+--S 39 of 288
+t2e:=exp(table2ex)
+--R 
+--R
+--R   (39)  1.0000006638 6725649999 9999999999 9569713175 574234992
+--R                                                                  Type: Float
+--E 39
+
+--S 40 of 288
+table2ey:=1.0000006638672564999999999999999569
+--R 
+--R
+--R   (40)  1.0000006638 6725649999 9999999999 9569
+--R                                                                  Type: Float
+--E 40
+
+--S 41 of 288
+t2e-table2ey
+--R 
+--R
+--R   (41)  0.7131755742 34992 E -34
+--R                                                                  Type: Float
+--E 41
+
+--S 42 of 288
+table2fx:=9.366572213364879E-7
+--R 
+--R
+--R   (42)  0.9366572213 364879 E -6
+--R                                                                  Type: Float
+--E 42
+
+--S 43 of 288
+t2f:=exp(table2fx)
+--R 
+--R
+--R   (43)  1.0000009366 5765999999 9999999999 9883070511 809163402
+--R                                                                  Type: Float
+--E 43
+
+--S 44 of 288
+table2fy:=1.0000009366576599999999999999999883
+--R 
+--R
+--R   (44)  1.0000009366 5765999999 9999999999 9883
+--R                                                                  Type: Float
+--E 44
+
+--S 45 of 288
+t2f-table2fy
+--R 
+--R
+--R   (45)  0.7051180916 34015 E -35
+--R                                                                  Type: Float
+--E 45
+
+--S 46 of 288
+table2gx:=7.970613003079781E-6
+--R 
+--R
+--R   (46)  0.0000079706 1300307978 1
+--R                                                                  Type: Float
+--E 46
+
+--S 47 of 288
+t2g:=exp(table2gx)
+--R 
+--R
+--R   (47)  1.0000079706 4476850000 0000000000 0362815663 769936294
+--R                                                                  Type: Float
+--E 47
+
+--S 48 of 288
+table2gy:=1.0000079706447685000000000000000362
+--R 
+--R
+--R   (48)  1.0000079706 4476850000 0000000000 0362
+--R                                                                  Type: Float
+--E 48
+
+--S 49 of 288
+t2g-table2gy
+--R 
+--R
+--R   (49)  0.8156637699 36294 E -34
+--R                                                                  Type: Float
+--E 49
+
+--S 50 of 288
+table2hx:=3.089765552852523E-5
+--R 
+--R
+--R   (50)  0.0000308976 5552852523
+--R                                                                  Type: Float
+--E 50
+
+--S 51 of 288
+t2h:=exp(table2hx)
+--R 
+--R
+--R   (51)  1.0000308981 3286600000 0000000000 0241262089 465734127
+--R                                                                  Type: Float
+--E 51
+
+--S 52 of 288
+table2hy:=1.0000308981328660000000000000000241
+--R 
+--R
+--R   (52)  1.0000308981 3286600000 0000000000 0241
+--R                                                                  Type: Float
+--E 52
+
+--S 53 of 288
+t2h-table2hy
+--R 
+--R
+--R   (53)  0.2620894657 34127 E -34
+--R                                                                  Type: Float
+--E 53
+
+--S 54 of 288
+table2ix:=1.302531956641873E-4
+--R 
+--R
+--R   (54)  0.0001302531 956641873
+--R                                                                  Type: Float
+--E 54
+
+--S 55 of 288
+t2i:=exp(table2ix)
+--R 
+--R
+--R   (55)  1.0001302616 7898000000 0000000000 0079860366 294631982
+--R                                                                  Type: Float
+--E 55
+
+--S 56 of 288
+table2iy:=1.00013026167898000000000000000000798
+--R 
+--R
+--R   (56)  1.0001302616 7898000000 0000000000 00798
+--R                                                                  Type: Float
+--E 56
+
+--S 57 of 288
+t2i-table2iy
+--R 
+--R
+--R   (57)  0.6036629463 19818 E -35
+--R                                                                  Type: Float
+--E 57
+
+--S 58 of 288
+table2jx:=2.241856702421245E-4
+--R 
+--R
+--R   (58)  0.0002241856 702421245
+--R                                                                  Type: Float
+--E 58
+
+--S 59 of 288
+t2j:=exp(table2jx)
+--R 
+--R
+--R   (59)  1.0002242108 0172750000 0000000000 0118637733 688720889
+--R                                                                  Type: Float
+--E 59
+
+--S 60 of 288
+table2jy:=1.0002242108017275000000000000000118
+--R 
+--R
+--R   (60)  1.0002242108 0172750000 0000000000 0118
+--R                                                                  Type: Float
+--E 60
+
+--S 61 of 288
+t2j-table2jy
+--R 
+--R
+--R   (61)  0.6377336887 20889 E -34
+--R                                                                  Type: Float
+--E 61
+
+--S 62 of 288
+table2kx:=7.230293679121590E-4
+--R 
+--R
+--R   (62)  0.0007230293 67912159
+--R                                                                  Type: Float
+--E 62
+
+--S 63 of 288
+t2k:=exp(table2kx)
+--R 
+--R
+--R   (63)  1.0007232908 1665349999 9999999999 9912755178 441089582
+--R                                                                  Type: Float
+--E 63
+
+--S 64 of 288
+table2ky:=1.00072329081665349999999999999999127
+--R 
+--R
+--R   (64)  1.0007232908 1665349999 9999999999 99127
+--R                                                                  Type: Float
+--E 64
+
+--S 65 of 288
+t2k-table2ky
+--R 
+--R
+--R   (65)  0.5517844108 9582 E -35
+--R                                                                  Type: Float
+--E 65
+
+--S 66 of 288
+table2lx:=5.259640428979129E-3
+--R 
+--R
+--R   (66)  0.0052596404 28979129
+--R                                                                  Type: Float
+--E 66
+
+--S 67 of 288
+t2l:=exp(table2lx)
+--R 
+--R
+--R   (67)  1.0052734966 1990949999 9999999999 9739699064 455042098
+--R                                                                  Type: Float
+--E 67
+
+--S 68 of 288
+table2ly:=1.0052734966199094999999999999999739
+--R 
+--R
+--R   (68)  1.0052734966 1990949999 9999999999 9739
+--R                                                                  Type: Float
+--E 68
+
+--S 69 of 288
+t2l-table2ly
+--R 
+--R
+--R   (69)  0.6990644550 42098 E -34
+--R                                                                  Type: Float
+--E 69
+
+--S 70 of 288
+table2mx:=9.407822313572878E-2
+--R 
+--R
+--R   (70)  0.0940782231 3572878
+--R                                                                  Type: Float
+--E 70
+
+--S 71 of 288
+t2m:=exp(table2mx)
+--R 
+--R
+--R   (71)  1.0986456820 6633850000 0000000000 0027805367 999050547
+--R                                                                  Type: Float
+--E 71
+
+--S 72 of 288
+table2my:=1.09864568206633850000000000000000278
+--R 
+--R
+--R   (72)  1.0986456820 6633850000 0000000000 00278
+--R                                                                  Type: Float
+--E 72
+
+--S 73 of 288
+t2m-table2my
+--R 
+--R
+--R   (73)  0.5367999050 547 E -36
+--R                                                                  Type: Float
+--E 73
+
+--S 74 of 288
+table2nx:=1.267914924960933E-1
+--R 
+--R
+--R   (74)  0.1267914924 960933
+--R                                                                  Type: Float
+--E 74
+
+--S 75 of 288
+t2n:=exp(table2nx)
+--R 
+--R
+--R   (75)  1.1351802994 9284300000 0000000000 0070604048 847780277
+--R                                                                  Type: Float
+--E 75
+
+--S 76 of 288
+table2ny:=1.13518029949284300000000000000000706
+--R 
+--R
+--R   (76)  1.1351802994 9284300000 0000000000 00706
+--R                                                                  Type: Float
+--E 76
+
+--S 77 of 288
+t2n-table2ny
+--R 
+--R
+--R   (77)  0.4048847780 277 E -36
+--R                                                                  Type: Float
+--E 77
+
+--S 78 of 288
+table2ox:=5.091077534282133E-1
+--R 
+--R
+--R   (78)  0.5091077534 282133
+--R                                                                  Type: Float
+--E 78
+
+--S 79 of 288
+t2o:=exp(table2ox)
+--R 
+--R
+--R   (79)  1.6638060072 6150950000 0000000000 0492443217 490289874
+--R                                                                  Type: Float
+--E 79
+
+--S 80 of 288
+table2oy:=1.6638060072615095000000000000000492
+--R 
+--R
+--R   (80)  1.6638060072 6150950000 0000000000 0492
+--R                                                                  Type: Float
+--E 80
+
+--S 81 of 288
+t2o-table2oy
+--R 
+--R
+--R   (81)  0.4432174902 89874 E -34
+--R                                                                  Type: Float
+--E 81
+
+--S 82 of 288
+table2px:=3.359104074009002
+--R 
+--R
+--R   (82)  3.3591040740 09002
+--R                                                                  Type: Float
+--E 82
+
+--S 83 of 288
+t2p:=exp(table2px)
+--R 
+--R
+--R   (83)  28.7634094457 2687500000 0000000000 0904859838 42482194
+--R                                                                  Type: Float
+--E 83
+
+--S 84 of 288
+table2py:=28.7634094457268750000000000000000904
+--R 
+--R
+--R   (84)  28.7634094457 2687500000 0000000000 0904
+--R                                                                  Type: Float
+--E 84
+
+--S 85 of 288
+t2p-table2py
+--R 
+--R
+--R   (85)  0.8598384248 2194 E -34
+--R                                                                  Type: Float
+--E 85
+
+--S 86 of 288
+table2qx:=19.10511686234796
+--R 
+--R
+--R   (86)  19.1051168623 4796
+--R                                                                  Type: Float
+--E 86
+
+--S 87 of 288
+t2q:=exp(table2qx)
+--R 
+--R
+--R   (87)  198265353.8414981999 9999999999 9997354256 3518374229 1
+--R                                                                  Type: Float
+--E 87
+
+--S 88 of 288
+table2qy:=1.9826535384149819999999999999999735E8
+--R 
+--R
+--R   (88)  198265353.8414981999 9999999999 999735
+--R                                                                  Type: Float
+--E 88
+
+--S 89 of 288
+t2q-table2qy
+--R 
+--R
+--R   (89)  0.4256351837 42291 E -26
+--R                                                                  Type: Float
+--E 89
+
+--S 90 of 288
+table2rx:=294.9551257293143
+--R 
+--R
+--R   (90)  294.9551257293 143
+--R                                                                  Type: Float
+--E 90
+
+--S 91 of 288
+t2r:=exp(table2rx)
+--R 
+--R
+--R   (91)  0.1251363586 6597895000 0000000000 0010873376 9483401177 E 129
+--R                                                                  Type: Float
+--E 91
+
+--S 92 of 288
+table2ry:=1.2513635866597895000000000000000108E128
+--R 
+--R
+--R   (92)  0.1251363586 6597895000 0000000000 00108 E 129
+--R                                                                  Type: Float
+--E 92
+
+--S 93 of 288
+t2r-table2ry
+--R 
+--R
+--R   (93)  0.7337694834 01177 E 94
+--R                                                                  Type: Float
+--E 93
+
+--S 94 of 288
+table2sx:=587.9131381356093
+--R 
+--R
+--R   (94)  587.9131381356 093
+--R                                                                  Type: Float
+--E 94
+
+--S 95 of 288
+t2s:=exp(table2sx)
+--R 
+--R
+--R   (95)  0.2125356221 8255224999 9999999999 9959486081 8097015346 E 256
+--R                                                                  Type: Float
+--E 95
+
+--S 96 of 288
+table2sy:=2.1253562218255224999999999999999594E255
+--R 
+--R
+--R   (96)  0.2125356221 8255224999 9999999999 99594 E 256
+--R                                                                  Type: Float
+--E 96
+
+--S 97 of 288
+t2s-table2sy
+--R 
+--R
+--R   (97)  0.8608180970 15346 E 221
+--R                                                                  Type: Float
+--E 97
+
+\end{chunk}
+
+Table 3 is all the worst cases of the decimal64 exponential function for
+$x \le -10^{-10}$, whose distance from a breakpoint is less than
+$5 x 10^{-17}$ ulp. The notation $d^k$ means that the digit $d$
+is repeated $k$ times.
+
+\begin{chunk}{*}
+
+--S 98 of 288
+table3ax:=-2.090862502185853E-9
+--R 
+--R
+--R   (98)  - 0.2090862502 185853 E -8
+--R                                                                  Type: Float
+--E 98
+
+--S 99 of 288
+t3a:=exp(table3ax)
+--R 
+--R
+--R   (99)  0.9999999979 0913750000 0000000000 0037126725 4778313484
+--R                                                                  Type: Float
+--E 99
+
+--S 100 of 288
+table3ay:=0.99999999790913750000000000000000371
+--R 
+--R
+--R   (100)  0.9999999979 0913750000 0000000000 00371
+--R                                                                  Type: Float
+--E 100
+
+--S 101 of 288
+t3a-table3ay
+--R 
+--R
+--R   (101)  0.2672547783 1348 E -35
+--R                                                                  Type: Float
+--E 101
+
+--S 102 of 288
+table3bx:=-3.803619857233762E-9
+--R 
+--R
+--R   (102)  - 0.3803619857 233762 E -8
+--R                                                                  Type: Float
+--E 102
+
+--S 103 of 288
+t3b:=exp(table3bx)
+--R 
+--R
+--R   (103)  0.9999999961 9638014999 9999999999 9984113979 4786371347
+--R                                                                  Type: Float
+--E 103
+
+--S 104 of 288
+table3by:=0.99999999619638014999999999999999841
+--R 
+--R
+--R   (104)  0.9999999961 9638014999 9999999999 99841
+--R                                                                  Type: Float
+--E 104
+
+--S 105 of 288
+t3b-table3by
+--R 
+--R
+--R   (105)  0.1397947863 7135 E -35
+--R                                                                  Type: Float
+--E 105
+
+--S 106 of 288
+table3cx:=-7.170496225708008E-9
+--R 
+--R
+--R   (106)  - 0.7170496225 708008 E -8
+--R                                                                  Type: Float
+--E 106
+
+--S 107 of 288
+t3c:=exp(table3cx)
+--R 
+--R
+--R   (107)  0.9999999928 2950380000 0000000000 0025224799 1338154446
+--R                                                                  Type: Float
+--E 107
+
+--S 108 of 288
+table3cy:=0.99999999282950380000000000000000252
+--R 
+--R
+--R   (108)  0.9999999928 2950380000 0000000000 00252
+--R                                                                  Type: Float
+--E 108
+
+--S 109 of 288
+t3c-table3cy
+--R 
+--R
+--R   (109)  0.2479913381 5445 E -35
+--R                                                                  Type: Float
+--E 109
+
+--S 110 of 288
+table3dx:=-9.362256793825926E-9
+--R 
+--R
+--R   (110)  - 0.9362256793 825926 E -8
+--R                                                                  Type: Float
+--E 110
+
+--S 111 of 288
+t3d:=exp(table3dx)
+--R 
+--R
+--R   (111)  0.9999999906 3774324999 9999999999 9958090794 3389658595
+--R                                                                  Type: Float
+--E 111
+
+--S 112 of 288
+table3dy:=0.99999999063774324999999999999999580
+--R 
+--R
+--R   (112)  0.9999999906 3774324999 9999999999 9958
+--R                                                                  Type: Float
+--E 112
+
+--S 113 of 288
+t3d-table3dy
+--R 
+--R
+--R   (113)  0.9079433896 58595 E -35
+--R                                                                  Type: Float
+--E 113
+
+--S 114 of 288
+table3ex:=-4.024416580979643E-8
+--R 
+--R
+--R   (114)  - 0.4024416580 979643 E -7
+--R                                                                  Type: Float
+--E 114
+
+--S 115 of 288
+t3e:=exp(table3ex)
+--R 
+--R
+--R   (115)  0.9999999597 5583500000 0000000000 0030839949 0551291379
+--R                                                                  Type: Float
+--E 115
+
+--S 116 of 288
+table3ey:=0.99999995975583500000000000000000308
+--R 
+--R
+--R   (116)  0.9999999597 5583500000 0000000000 00308
+--R                                                                  Type: Float
+--E 116
+
+--S 117 of 288
+t3e-table3ey
+--R 
+--R
+--R   (117)  0.3994905512 91379 E -35
+--R                                                                  Type: Float
+--E 117
+
+--S 118 of 288
+table3fx:=-6.306378165019860E-7
+--R 
+--R
+--R   (118)  - 0.6306378165 01986 E -6
+--R                                                                  Type: Float
+--E 118
+
+--S 119 of 288
+t3f:=exp(table3fx)
+--R 
+--R
+--R   (119)  0.9999993693 6238235000 0000000000 0030198486 9980386153
+--R                                                                  Type: Float
+--E 119
+
+--S 120 of 288
+table3fy:=0.99999936936238235000000000000000301
+--R 
+--R
+--R   (120)  0.9999993693 6238235000 0000000000 00301
+--R                                                                  Type: Float
+--E 120
+
+--S 121 of 288
+t3f-table3fy
+--R 
+--R
+--R   (121)  0.9848699803 86153 E -35
+--R                                                                  Type: Float
+--E 121
+
+--S 122 of 288
+table3gx:=-7.720146779532548E-7
+--R 
+--R
+--R   (122)  - 0.7720146779 532548 E -6
+--R                                                                  Type: Float
+--E 122
+
+--S 123 of 288
+t3g:=exp(table3gx)
+--R 
+--R
+--R   (123)  0.9999992279 8562004999 9999999999 9961275219 425019545
+--R                                                                  Type: Float
+--E 123
+
+--S 124 of 288
+table3gy:=0.99999922798562004999999999999999612
+--R 
+--R
+--R   (124)  0.9999992279 8562004999 9999999999 99612
+--R                                                                  Type: Float
+--E 124
+
+--S 125 of 288
+t3g-table3gy
+--R 
+--R
+--R   (125)  0.7521942501 95449 E -35
+--R                                                                  Type: Float
+--E 125
+
+--S 126 of 288
+table3hx:=-9.753167969712726E-7
+--R 
+--R
+--R   (126)  - 0.9753167969 712726 E -6
+--R                                                                  Type: Float
+--E 126
+
+--S 127 of 288
+t3h:=exp(table3hx)
+--R 
+--R
+--R   (127)  0.9999990246 8367864999 9999999999 9991202359 4289724846
+--R                                                                  Type: Float
+--E 127
+
+--S 128 of 288
+table3hy:=0.999999024683678649999999999999999120
+--R 
+--R
+--R   (128)  0.9999990246 8367864999 9999999999 99912
+--R                                                                  Type: Float
+--E 128
+
+--S 129 of 288
+t3h-table3hy
+--R 
+--R
+--R   (129)  0.2359428972 485 E -36
+--R                                                                  Type: Float
+--E 129
+
+--S 130 of 288
+table3ix:=-5.911964024384330E-5
+--R 
+--R
+--R   (130)  - 0.0000591196 402438433
+--R                                                                  Type: Float
+--E 130
+
+--S 131 of 288
+t3i:=exp(table3ix)
+--R 
+--R
+--R   (131)  0.9999408821 0728765000 0000000000 0038489594 1622665923
+--R                                                                  Type: Float
+--E 131
+
+--S 132 of 288
+table3iy:=0.99994088210728765000000000000000384
+--R 
+--R
+--R   (132)  0.9999408821 0728765000 0000000000 00384
+--R                                                                  Type: Float
+--E 132
+
+--S 133 of 288
+t3i-table3iy
+--R 
+--R
+--R   (133)  0.8959416226 65923 E -35
+--R                                                                  Type: Float
+--E 133
+
+--S 134 of 288
+table3jx:=-8.232272117182855E-5
+--R 
+--R
+--R   (134)  - 0.0000823227 2117182855
+--R                                                                  Type: Float
+--E 134
+
+--S 135 of 288
+t3j:=exp(table3jx)
+--R 
+--R
+--R   (135)  0.9999176806 6725040000 0000000000 0031272715 7320394822
+--R                                                                  Type: Float
+--E 135
+
+--S 136 of 288
+table3jy:=0.99991768066725040000000000000000312
+--R 
+--R
+--R   (136)  0.9999176806 6725040000 0000000000 00312
+--R                                                                  Type: Float
+--E 136
+
+--S 137 of 288
+t3j-table3jy
+--R 
+--R
+--R   (137)  0.7271573203 94822 E -35
+--R                                                                  Type: Float
+--E 137
+
+--S 138 of 288
+table3kx:=-8.232461306131942E-5
+--R 
+--R
+--R   (138)  - 0.0000823246 1306131942
+--R                                                                  Type: Float
+--E 138
+
+--S 139 of 288
+t3k:=exp(table3kx)
+--R 
+--R
+--R   (139)  0.9999176787 7551664999 9999999999 9955576707 8594207526
+--R                                                                  Type: Float
+--E 139
+
+--S 140 of 288
+table3ky:=0.99991767877551664999999999999999555
+--R 
+--R
+--R   (140)  0.9999176787 7551664999 9999999999 99555
+--R                                                                  Type: Float
+--E 140
+
+--S 141 of 288
+t3k-table3ky
+--R 
+--R
+--R   (141)  0.7670785942 07526 E -35
+--R                                                                  Type: Float
+--E 141
+
+--S 142 of 288
+table3lx:=-8.496743395712491E-2
+--R 
+--R
+--R   (142)  - 0.0849674339 5712491
+--R                                                                  Type: Float
+--E 142
+
+--S 143 of 288
+t3l:=exp(table3lx)
+--R 
+--R
+--R   (143)  0.9185421971 9896054999 9999999999 9984320060 4468310134
+--R                                                                  Type: Float
+--E 143
+
+--S 144 of 288
+table3ly:=0.91854219719896054999999999999999843
+--R 
+--R
+--R   (144)  0.9185421971 9896054999 9999999999 99843
+--R                                                                  Type: Float
+--E 144
+
+--S 145 of 288
+t3l-table3ly
+--R 
+--R
+--R   (145)  0.2006044683 1013 E -35
+--R                                                                  Type: Float
+--E 145
+
+--S 146 of 288
+table3mx:=-9.250971335383380E-2
+--R 
+--R
+--R   (146)  - 0.0925097133 538338
+--R                                                                  Type: Float
+--E 146
+
+--S 147 of 288
+t3m:=exp(table3mx)
+--R 
+--R
+--R   (147)  0.9116403558 3610989999 9999999999 9956380374 9072231327
+--R                                                                  Type: Float
+--E 147
+
+--S 148 of 288
+table3my:=0.91164035583610989999999999999999563
+--R 
+--R
+--R   (148)  0.9116403558 3610989999 9999999999 99563
+--R                                                                  Type: Float
+--E 148
+
+--S 149 of 288
+t3m-table3my
+--R 
+--R
+--R   (149)  0.8037490722 31327 E -35
+--R                                                                  Type: Float
+--E 149
+
+--S 150 of 288
+table3nx:=-9.337621398029658E-2
+--R 
+--R
+--R   (150)  - 0.0933762139 8029658
+--R                                                                  Type: Float
+--E 150
+
+--S 151 of 288
+t3n:=exp(table3nx)
+--R 
+--R
+--R   (151)  0.9108507610 3826650000 0000000000 0040013766 8727220579
+--R                                                                  Type: Float
+--E 151
+
+--S 152 of 288
+table3ny:=0.91085076103826650000000000000000400
+--R 
+--R
+--R   (152)  0.9108507610 3826650000 0000000000 004
+--R                                                                  Type: Float
+--E 152
+
+--S 153 of 288
+t3n-table3ny
+--R 
+--R
+--R   (153)  0.1376687272 2058 E -35
+--R                                                                  Type: Float
+--E 153
+
+--S 154 of 288
+table3ox:=-9.341228128742237E-2
+--R 
+--R
+--R   (154)  - 0.0934122812 8742237
+--R                                                                  Type: Float
+--E 154
+
+--S 155 of 288
+t3o:=exp(table3ox)
+--R 
+--R
+--R   (155)  0.9108179096 9655564999 9999999999 9995875465 54011791
+--R                                                                  Type: Float
+--E 155
+
+--S 156 of 288
+table3oy:=0.910817909696555649999999999999999587
+--R 
+--R
+--R   (156)  0.9108179096 9655564999 9999999999 999587
+--R                                                                  Type: Float
+--E 156
+
+--S 157 of 288
+t3o-table3oy
+--R 
+--R
+--R   (157)  0.5465540117 91 E -36
+--R                                                                  Type: Float
+--E 157
+
+--S 158 of 288
+table3px:=-9.998733949173545E-2
+--R 
+--R
+--R   (158)  - 0.0999873394 9173545
+--R                                                                  Type: Float
+--E 158
+
+--S 159 of 288
+t3p:=exp(table3px)
+--R 
+--R
+--R   (159)  0.9048488738 1008650000 0000000000 0033076194 2534636856
+--R                                                                  Type: Float
+--E 159
+
+--S 160 of 288
+table3py:=0.90484887381008650000000000000000330
+--R 
+--R
+--R   (160)  0.9048488738 1008650000 0000000000 0033
+--R                                                                  Type: Float
+--E 160
+
+--S 161 of 288
+t3p-table3py
+--R 
+--R
+--R   (161)  0.7619425346 36856 E -35
+--R                                                                  Type: Float
+--E 161
+
+--S 162 of 288
+table3qx:=-1.452866822458144
+--R 
+--R
+--R   (162)  - 1.4528668224 58144
+--R                                                                  Type: Float
+--E 162
+
+--S 163 of 288
+t3q:=exp(table3qx)
+--R 
+--R
+--R   (163)  0.2338987797 3141290000 0000000000 0041311743 3341591011
+--R                                                                  Type: Float
+--E 163
+
+--S 164 of 288
+table3qy:=0.23389877973141290000000000000000413
+--R 
+--R
+--R   (164)  0.2338987797 3141290000 0000000000 00413
+--R                                                                  Type: Float
+--E 164
+
+--S 165 of 288
+t3q-table3qy
+--R 
+--R
+--R   (165)  0.1174333415 91011 E -35
+--R                                                                  Type: Float
+--E 165
+
+--S 166 of 288
+table3rx:=-5.085363904672046
+--R 
+--R
+--R   (166)  - 5.0853639046 72046
+--R                                                                  Type: Float
+--E 166
+
+--S 167 of 288
+t3r:=exp(table3rx)
+--R 
+--R
+--R   (167)  0.0061866353 3511597549 9999999999 9999774966 5221424755 88
+--R                                                                  Type: Float
+--E 167
+
+--S 168 of 288
+table3ry:=6.1866353351159754999999999999999774E-3
+--R 
+--R
+--R   (168)  0.0061866353 3511597549 9999999999 9999774
+--R                                                                  Type: Float
+--E 168
+
+--S 169 of 288
+t3r-table3ry
+--R 
+--R
+--R   (169)  0.9665221424 75588 E -37
+--R                                                                  Type: Float
+--E 169
+
+--S 170 of 288
+table3sx:=-5.815903811599861
+--R 
+--R
+--R   (170)  - 5.8159038115 99861
+--R                                                                  Type: Float
+--E 170
+
+--S 171 of 288
+t3s:=exp(table3sx)
+--R 
+--R
+--R   (171)  0.0029797859 4494580450 0000000000 0000173080 4093500054 44
+--R                                                                  Type: Float
+--E 171
+
+--S 172 of 288
+table3sy:=2.9797859449458045000000000000000173E-3
+--R 
+--R
+--R   (172)  0.0029797859 4494580450 0000000000 0000173
+--R                                                                  Type: Float
+--E 172
+
+--S 173 of 288
+t3s-table3sy
+--R 
+--R
+--R   (173)  0.8040935000 5444 E -38
+--R                                                                  Type: Float
+--E 173
+
+--S 174 of 288
+table3tx:=-11.93382527979436
+--R 
+--R
+--R   (174)  - 11.9338252797 9436
+--R                                                                  Type: Float
+--E 174
+
+--S 175 of 288
+t3t:=exp(table3tx)
+--R 
+--R
+--R   (175)  0.0000065645 5865261145 6999999999 9999999658 7484497146 90131
+--R                                                                  Type: Float
+--E 175
+
+--S 176 of 288
+table3ty:=6.5645586526114569999999999999999658E-6
+--R 
+--R
+--R   (176)  0.0000065645 5865261145 6999999999 9999999658
+--R                                                                  Type: Float
+--E 176
+
+--S 177 of 288
+t3t-table3ty
+--R 
+--R
+--R   (177)  0.7484497146 90131 E -40
+--R                                                                  Type: Float
+--E 177
+
+--S 178 of 288
+table3ux:=-46.84177248885496
+--R 
+--R
+--R   (178)  - 46.8417724888 5496
+--R                                                                  Type: Float
+--E 178
+
+--S 179 of 288
+t3u:=exp(table3ux)
+--R 
+--R
+--R   (179)  0.4538127418 2205359999 9999999999 9976996689 5333158931 E -20
+--R                                                                  Type: Float
+--E 179
+
+--S 180 of 288
+table3uy:=4.5381274182205359999999999999999769E-21
+--R 
+--R
+--R   (180)  0.4538127418 2205359999 9999999999 99769 E -20
+--R                                                                  Type: Float
+--E 180
+
+--S 181 of 288
+t3u-table3uy
+--R 
+--R
+--R   (181)  0.9668953331 58931 E -55
+--R                                                                  Type: Float
+--E 181
+
+--S 182 of 288
+table3vx:=-84.88922783213444
+--R 
+--R
+--R   (182)  - 84.8892278321 3444
+--R                                                                  Type: Float
+--E 182
+
+--S 183 of 288
+t3v:=exp(table3vx)
+--R 
+--R
+--R   (183)  0.1358553605 7843999891 2340715182 5158925719 9577954788 E -36
+--R                                                                  Type: Float
+--E 183
+
+--S 184 of 288
+table3vy:=1.3599128388934695000000000000000266E-37
+--R 
+--R
+--R   (184)  0.1359912838 8934695000 0000000000 00266 E -36
+--R                                                                  Type: Float
+--E 184
+
+--S 185 of 288
+t3v-table3vy
+--R 
+--R
+--R   (185)  - 0.1359233109 0695108765 9284817486 7674280042 2045212 E -39
+--R                                                                  Type: Float
+--E 185
+
+--S 186 of 288
+table3wx:=-495.9839910528425
+--R 
+--R
+--R   (186)  - 495.9839910528 425
+--R                                                                  Type: Float
+--E 186
+
+--S 187 of 288
+t3w:=exp(table3wx)
+--R 
+--R
+--R   (187)  0.3952661043 0311695000 0000000000 0037150791 9467288834 E -215
+--R                                                                  Type: Float
+--E 187
+
+--S 188 of 288
+table3wy:=3.9526610430311695000000000000000371E-216
+--R 
+--R
+--R   (188)  0.3952661043 0311695000 0000000000 00371 E -215
+--R                                                                  Type: Float
+--E 188
+
+--S 189 of 288
+t3w-table3wy
+--R 
+--R
+--R   (189)  0.5079194672 88834 E -250
+--R                                                                  Type: Float
+--E 189
+
+--S 190 of 288
+table3xx:=-524.2585830842744
+--R 
+--R
+--R   (190)  - 524.2585830842 744
+--R                                                                  Type: Float
+--E 190
+
+--S 191 of 288
+t3x:=exp(table3xx)
+--R 
+--R
+--R   (191)  0.2076778963 8678450000 0000000000 0028745873 4089244785 E -227
+--R                                                                  Type: Float
+--E 191
+
+--S 192 of 288
+table3xy:=2.0767789638678450000000000000000287E-228
+--R 
+--R
+--R   (192)  0.2076778963 8678450000 0000000000 00287 E -227
+--R                                                                  Type: Float
+--E 192
+
+--S 193 of 288
+t3x-table3xy
+--R 
+--R
+--R   (193)  0.4587340892 44785 E -262
+--R                                                                  Type: Float
+--E 193
+
+\end{chunk}
+
+Table 4 is some bad cases of the exponential function in the decimal64
+format, for 
+\[e^+ = 4.999999999999999{\rm x}10^{-16} \le x < 10^{-9}\].
+At most two bad cases (the worst ones) are given per exponent.
+
+\begin{chunk}{*}
+
+--S 194 of 288
+table4ax:=6.000119998199928E-10
+--R 
+--R
+--R   (194)  0.6000119998 199928 E -9
+--R                                                                  Type: Float
+--E 194
+
+--S 195 of 288
+t4a:=exp(table4ax)
+--R 
+--R
+--R   (195)  1.0000000006 0001199999 9999999999 9956799459 99423978
+--R                                                                  Type: Float
+--E 195
+
+--S 196 of 288
+table4ay:=1.00000000060001199999999999999999567
+--R 
+--R
+--R   (196)  1.0000000006 0001199999 9999999999 99567
+--R                                                                  Type: Float
+--E 196
+
+--S 197 of 288
+t4a-table4ay
+--R 
+--R
+--R   (197)  0.9945999423 97797 E -35
+--R                                                                  Type: Float
+--E 197
+
+--S 198 of 288
+table4bx:=5.999879998200072E-10
+--R 
+--R
+--R   (198)  0.5999879998 200072 E -9
+--R                                                                  Type: Float
+--E 198
+
+--S 199 of 288
+t4b:=exp(table4bx)
+--R 
+--R
+--R   (199)  1.0000000005 9998800000 0000000000 0043199460 00575978
+--R                                                                  Type: Float
+--E 199
+
+--S 200 of 288
+table4by:=1.00000000059998800000000000000000431
+--R 
+--R
+--R   (200)  1.0000000005 9998800000 0000000000 00431
+--R                                                                  Type: Float
+--E 200
+
+--S 201 of 288
+t4b-table4by
+--R 
+--R
+--R   (201)  0.9946000575 97797 E -35
+--R                                                                  Type: Float
+--E 201
+
+--S 202 of 288
+table4cx:=1.039999999994592E-11
+--R 
+--R
+--R   (202)  0.1039999999 994592 E -10
+--R                                                                  Type: Float
+--E 202
+
+--S 203 of 288
+t4c:=exp(table4cx)
+--R 
+--R
+--R   (203)  1.0000000000 1039999999 9999999999 9996250453 333323584
+--R                                                                  Type: Float
+--E 203
+
+--S 204 of 288
+table4cy:=1.000000000010399999999999999999999625
+--R 
+--R
+--R   (204)  1.0000000000 1039999999 9999999999 999625
+--R                                                                  Type: Float
+--E 204
+
+--S 205 of 288
+t4c-table4cy
+--R 
+--R
+--R   (205)  0.4533333235 84 E -37
+--R                                                                  Type: Float
+--E 205
+
+--S 206 of 288
+table4dx:=1.019999999994798E-11
+--R 
+--R
+--R   (206)  0.1019999999 994798 E -10
+--R                                                                  Type: Float
+--E 206
+
+--S 207 of 288
+t4d:=exp(table4dx)
+--R 
+--R
+--R   (207)  1.0000000000 1019999999 9999999999 9996462639 99999098
+--R                                                                  Type: Float
+--E 207
+
+--S 208 of 288
+table4dy:=1.000000000010199999999999999999999646
+--R 
+--R
+--R   (208)  1.0000000000 1019999999 9999999999 999646
+--R                                                                  Type: Float
+--E 208
+
+--S 209 of 288
+t4d-table4dy
+--R 
+--R
+--R   (209)  0.2639999990 98 E -36
+--R                                                                  Type: Float
+--E 209
+
+--S 210 of 288
+table4ex:=1.199999999999280E-12
+--R 
+--R
+--R   (210)  0.1199999999 99928 E -11
+--R                                                                  Type: Float
+--E 210
+
+--S 211 of 288
+t4e:=exp(table4ex)
+--R 
+--R
+--R   (211)  1.0000000000 0119999999 9999999999 9999994239 999999998
+--R                                                                  Type: Float
+--E 211
+
+--S 212 of 288
+table4ey:=1.000000000001199999999999999999999999423
+--R 
+--R
+--R   (212)  1.0000000000 0119999999 9999999999 999999423
+--R                                                                  Type: Float
+--E 212
+
+--S 213 of 288
+t4e-table4ey
+--R 
+--R
+--R   (213)  0.9999999998 3 E -39
+--R                                                                  Type: Float
+--E 213
+
+--S 214 of 288
+table4fx:=1.099999999999395E-12
+--R 
+--R
+--R   (214)  0.1099999999 999395 E -11
+--R                                                                  Type: Float
+--E 214
+
+--S 215 of 288
+t4f:=exp(table4fx)
+--R 
+--R
+--R   (215)  1.0000000000 0109999999 9999999999 9999995563 333333332
+--R                                                                  Type: Float
+--E 215
+
+--S 216 of 288
+table4fy:=1.000000000001099999999999999999999999556
+--R 
+--R
+--R   (216)  1.0000000000 0109999999 9999999999 999999556
+--R                                                                  Type: Float
+--E 216
+
+--S 217 of 288
+t4f-table4fy
+--R 
+--R
+--R   (217)  0.3333333332 E -39
+--R                                                                  Type: Float
+--E 217
+
+--S 218 of 288
+table4gx:=1.399999999999902E-13
+--R 
+--R
+--R   (218)  0.1399999999 999902 E -12
+--R                                                                  Type: Float
+--E 218
+
+--S 219 of 288
+t4g:=exp(table4gx)
+--R 
+--R
+--R   (219)  1.0000000000 0013999999 9999999999 9999999990 853333333
+--R                                                                  Type: Float
+--E 219
+
+--S 220 of 288
+table4gy:=1.000000000000139999999999999999999999999085
+--R 
+--R
+--R   (220)  1.0000000000 0013999999 9999999999 9999999990 85
+--R                                                                  Type: Float
+--E 220
+
+--S 221 of 288
+t4g-table4gy
+--R 
+--R
+--R   (221)  0.3333333 E -42
+--R                                                                  Type: Float
+--E 221
+
+--S 222 of 288
+table4hx:=1.199999999999928E-13
+--R 
+--R
+--R   (222)  0.1199999999 999928 E -12
+--R                                                                  Type: Float
+--E 222
+
+--S 223 of 288
+t4h:=exp(table4hx)
+--R 
+--R
+--R   (223)  1.0000000000 0011999999 9999999999 9999999994 24
+--R                                                                  Type: Float
+--E 223
+
+--S 224 of 288
+table4hy:=1.000000000000119999999999999999999999999423
+--R 
+--R
+--R   (224)  1.0000000000 0011999999 9999999999 9999999994 23
+--R                                                                  Type: Float
+--E 224
+
+--S 225 of 288
+t4h-table4hy
+--R 
+--R
+--R   (225)  0.1 E -41
+--R                                                                  Type: Float
+--E 225
+
+--S 226 of 288
+table4ix:=2.999999999999955E-14
+--R 
+--R
+--R   (226)  0.2999999999 999955 E -13
+--R                                                                  Type: Float
+--E 226
+
+--S 227 of 288
+t4i:=exp(table4ix)
+--R 
+--R
+--R   (227)  1.0000000000 0002999999 9999999999 9999999999 91
+--R                                                                  Type: Float
+--E 227
+
+--S 228 of 288
+table4iy:=1.00000000000002999999999999999999999999999099
+--R 
+--R
+--R   (228)  1.0000000000 0002999999 9999999999 9999999999 9099
+--R                                                                  Type: Float
+--E 228
+
+--S 229 of 288
+t4i-table4iy
+--R 
+--R
+--R   (229)  0.1 E -43
+--R                                                                  Type: Float
+--E 229
+
+--S 230 of 288
+table4jx:=1.999999999999980E-14
+--R 
+--R
+--R   (230)  0.1999999999 99998 E -13
+--R                                                                  Type: Float
+--E 230
+
+--S 231 of 288
+t4j:=exp(table4jx)
+--R 
+--R
+--R   (231)  1.0000000000 0001999999 9999999999 9999999999 973333333
+--R                                                                  Type: Float
+--E 231
+
+--S 232 of 288
+table4jy:=1.00000000000001999999999999999999999999999733
+--R 
+--R
+--R   (232)  1.0000000000 0001999999 9999999999 9999999999 9733
+--R                                                                  Type: Float
+--E 232
+
+--S 233 of 288
+t4j-table4jy
+--R 
+--R
+--R   (233)  0.33333 E -44
+--R                                                                  Type: Float
+--E 233
+
+--S 234 of 288
+table4kx:=3.999999999999992E-15
+--R 
+--R
+--R   (234)  0.3999999999 999992 E -14
+--R                                                                  Type: Float
+--E 234
+
+--S 235 of 288
+t4k:=exp(table4kx)
+--R 
+--R
+--R   (235)  1.0000000000 0000399999 9999999999 9999999999 999786667
+--R                                                                  Type: Float
+--E 235
+
+--S 236 of 288
+table4ky:=1.0000000000000039999999999999999999999999999786
+--R 
+--R
+--R   (236)  1.0000000000 0000399999 9999999999 9999999999 999786
+--R                                                                  Type: Float
+--E 236
+
+--S 237 of 288
+t4k-table4ky
+--R 
+--R
+--R   (237)  0.667 E -46
+--R                                                                  Type: Float
+--E 237
+
+--S 238 of 288
+table4lx:=1.999999999999998E-15
+--R 
+--R
+--R   (238)  0.1999999999 999998 E -14
+--R                                                                  Type: Float
+--E 238
+
+--S 239 of 288
+t4l:=exp(table4lx)
+--R 
+--R
+--R   (239)  1.0000000000 0000199999 9999999999 9999999999 999973333
+--R                                                                  Type: Float
+--E 239
+
+--S 240 of 288
+table4ly:=1.00000000000000199999999999999999999999999999733
+--R 
+--R
+--R   (240)  1.0000000000 0000199999 9999999999 9999999999 9999733
+--R                                                                  Type: Float
+--E 240
+
+--S 241 of 288
+t4l-table4ly
+--R 
+--R
+--R   (241)  0.33 E -47
+--R                                                                  Type: Float
+--E 241
+
+--S 242 of 288
+table4mx:=9.999999999999995E-16
+--R 
+--R
+--R   (242)  0.9999999999 999995 E -15
+--R                                                                  Type: Float
+--E 242
+
+--S 243 of 288
+t4m:=exp(table4mx)
+--R 
+--R
+--R   (243)  1.0000000000 0000099999 9999999999 9999999999 999996667
+--R                                                                  Type: Float
+--E 243
+
+--S 244 of 288
+table4my:=1.000000000000000999999999999999999999999999999666
+--R 
+--R
+--R   (244)  1.0000000000 0000099999 9999999999 9999999999 99999666
+--R                                                                  Type: Float
+--E 244
+
+--S 245 of 288
+t4m-table4my
+--R 
+--R
+--R   (245)  0.7 E -48
+--R                                                                  Type: Float
+--E 245
+
+\end{chunk}
+
+Table 5 is some bad cases of the exponential function in the decimal64
+format, for
+\[-10^{-10} < x \le b^- = -5.000000000000001{\rm x}10^{-17}\]
+At most two bad cases (the worst ones) are given per exponent.
+
+\begin{chunk}{*}
+
+--S 246 of 288
+table5ax:=-1.020000000005202E-11
+--R 
+--R
+--R   (246)  - 0.1020000000 005202 E -10
+--R                                                                  Type: Float
+--E 246
+
+--S 247 of 288
+t5a:=exp(table5ax)
+--R 
+--R
+--R   (247)  0.9999999999 8980000000 0000000000 0003537359 9999909797
+--R                                                                  Type: Float
+--E 247
+
+--S 248 of 288
+table5ay:=0.999999999989800000000000000000000353
+--R 
+--R
+--R   (248)  0.9999999999 8980000000 0000000000 000353
+--R                                                                  Type: Float
+--E 248
+
+--S 249 of 288
+t5a-table5ay
+--R 
+--R
+--R   (249)  0.7359999990 9797 E -36
+--R                                                                  Type: Float
+--E 249
+
+--S 250 of 288
+table5bx:=-1.000000000005000E-11
+--R 
+--R
+--R   (250)  - 0.1000000000 005 E -10
+--R                                                                  Type: Float
+--E 250
+
+--S 251 of 288
+t5b:=exp(table5bx)
+--R 
+--R
+--R   (251)  0.9999999999 9000000000 0000000000 0003333333 333325
+--R                                                                  Type: Float
+--E 251
+
+--S 252 of 288
+table5by:=0.999999999990000000000000000000000333
+--R 
+--R
+--R   (252)  0.9999999999 9000000000 0000000000 000333
+--R                                                                  Type: Float
+--E 252
+
+--S 253 of 288
+t5b-table5by
+--R 
+--R
+--R   (253)  0.3333333325 E -36
+--R                                                                  Type: Float
+--E 253
+
+--S 254 of 288
+table5cx:=-1.100000000000605E-12
+--R 
+--R
+--R   (254)  - 0.1100000000 000605 E -11
+--R                                                                  Type: Float
+--E 254
+
+--S 255 of 288
+t5c:=exp(table5cx)
+--R 
+--R
+--R   (255)  0.9999999999 9890000000 0000000000 0000004436 6666666654
+--R                                                                  Type: Float
+--E 255
+
+--S 256 of 288
+table5cy:=0.999999999998900000000000000000000000443
+--R 
+--R
+--R   (256)  0.9999999999 9890000000 0000000000 000000443
+--R                                                                  Type: Float
+--E 256
+
+--S 257 of 288
+t5c-table5cy
+--R 
+--R
+--R   (257)  0.6666666665 4 E -39
+--R                                                                  Type: Float
+--E 257
+
+--S 258 of 288
+table5dx:=-1.000000000000500E-12
+--R 
+--R
+--R   (258)  - 0.1000000000 0005 E -11
+--R                                                                  Type: Float
+--E 258
+
+--S 259 of 288
+t5d:=exp(table5dx)
+--R 
+--R
+--R   (259)  0.9999999999 9900000000 0000000000 0000003333 3333333325
+--R                                                                  Type: Float
+--E 259
+
+--S 260 of 288
+table5dy:=0.999999999999000000000000000000000000333
+--R 
+--R
+--R   (260)  0.9999999999 9900000000 0000000000 000000333
+--R                                                                  Type: Float
+--E 260
+
+--S 261 of 288
+t5d-table5dy
+--R 
+--R
+--R   (261)  0.3333333332 E -39
+--R                                                                  Type: Float
+--E 261
+
+--S 262 of 288
+table5ex:=-1.200000000000072E-13
+--R 
+--R
+--R   (262)  - 0.1200000000 000072 E -12
+--R                                                                  Type: Float
+--E 262
+
+--S 263 of 288
+t5e:=exp(table5ex)
+--R 
+--R
+--R   (263)  0.9999999999 9988000000 0000000000 0000000005 76
+--R                                                                  Type: Float
+--E 263
+
+--S 264 of 288
+table5ey:=0.999999999999880000000000000000000000000575
+--R 
+--R
+--R   (264)  0.9999999999 9988000000 0000000000 0000000005 75
+--R                                                                  Type: Float
+--E 264
+
+--S 265 of 288
+t5e-table5ey
+--R 
+--R
+--R   (265)  0.1 E -41
+--R                                                                  Type: Float
+--E 265
+
+--S 266 of 288
+table5fx:=-1.000000000000050E-13
+--R 
+--R
+--R   (266)  - 0.1000000000 00005 E -12
+--R                                                                  Type: Float
+--E 266
+
+--S 267 of 288
+t5f:=exp(table5fx)
+--R 
+--R
+--R   (267)  0.9999999999 9990000000 0000000000 0000000003 3333333333
+--R                                                                  Type: Float
+--E 267
+
+--S 268 of 288
+table5fy:=0.999999999999900000000000000000000000000333
+--R 
+--R
+--R   (268)  0.9999999999 9990000000 0000000000 0000000003 33
+--R                                                                  Type: Float
+--E 268
+
+--S 269 of 288
+t5f-table5fy
+--R 
+--R
+--R   (269)  0.3333333 E -42
+--R                                                                  Type: Float
+--E 269
+
+--S 270 of 288
+table5gx:=-2.000000000000020E-14
+--R 
+--R
+--R   (270)  - 0.2000000000 00002 E -13
+--R                                                                  Type: Float
+--E 270
+
+--S 271 of 288
+t5g:=exp(table5gx)
+--R 
+--R
+--R   (271)  0.9999999999 9998000000 0000000000 0000000000 0266666667
+--R                                                                  Type: Float
+--E 271
+
+--S 272 of 288
+table5gy:=0.99999999999998000000000000000000000000000266
+--R 
+--R
+--R   (272)  0.9999999999 9998000000 0000000000 0000000000 0266
+--R                                                                  Type: Float
+--E 272
+
+--S 273 of 288
+t5g-table5gy
+--R 
+--R
+--R   (273)  0.666667 E -44
+--R                                                                  Type: Float
+--E 273
+
+--S 274 of 288
+table5hx:=-1.000000000000005E-14
+--R 
+--R
+--R   (274)  - 0.1000000000 000005 E -13
+--R                                                                  Type: Float
+--E 274
+
+--S 275 of 288
+t5h:=exp(table5hx)
+--R 
+--R
+--R   (275)  0.9999999999 9999000000 0000000000 0000000000 0033333333
+--R                                                                  Type: Float
+--E 275
+
+--S 276 of 288
+table5hy:=0.999999999999990000000000000000000000000000333          
+--R 
+--R
+--R   (276)  0.9999999999 9999000000 0000000000 0000000000 00333
+--R                                                                  Type: Float
+--E 276
+
+--S 277 of 288
+t5h-table5hy
+--R 
+--R
+--R   (277)  0.3333 E -45
+--R                                                                  Type: Float
+--E 277
+
+--S 278 of 288
+table5ix:=-4.000000000000008E-15
+--R 
+--R
+--R   (278)  - 0.4000000000 000008 E -14
+--R                                                                  Type: Float
+--E 278
+
+--S 279 of 288
+t5i:=exp(table5ix)
+--R 
+--R
+--R   (279)  0.9999999999 9999600000 0000000000 0000000000 0002133333
+--R                                                                  Type: Float
+--E 279
+
+--S 280 of 288
+table5iy:=0.9999999999999960000000000000000000000000000213
+--R 
+--R
+--R   (280)  0.9999999999 9999600000 0000000000 0000000000 000213
+--R                                                                  Type: Float
+--E 280
+
+--S 281 of 288
+t5i-table5iy
+--R 
+--R
+--R   (281)  0.333 E -46
+--R                                                                  Type: Float
+--E 281
+
+--S 282 of 288
+table5jx:=-2.000000000000002E-15
+--R 
+--R
+--R   (282)  - 0.2000000000 000002 E -14
+--R                                                                  Type: Float
+--E 282
+
+--S 283 of 288
+t5j:=exp(table5jx)
+--R 
+--R
+--R   (283)  0.9999999999 9999800000 0000000000 0000000000 0000266667
+--R                                                                  Type: Float
+--E 283
+
+--S 284 of 288
+table5jy:=0.99999999999999800000000000000000000000000000266
+--R 
+--R
+--R   (284)  0.9999999999 9999800000 0000000000 0000000000 0000266
+--R                                                                  Type: Float
+--E 284
+
+--S 285 of 288
+t5j-table5jy
+--R 
+--R
+--R   (285)  0.667 E -47
+--R                                                                  Type: Float
+--E 285
+
+--S 286 of 288
+a1:=9.407822313572878E-2
+--R 
+--R
+--R   (286)  0.0940782231 3572878
+--R                                                                  Type: Float
+--E 286
+
+--S 287 of 288
+a2:=exp(a1)
+--R 
+--R
+--R   (287)  1.0986456820 6633850000 0000000000 0027805367 999050547
+--R                                                                  Type: Float
+--E 287
+
+--S 288 of 288
+a2-1.09864568206633850000000000000000278
+--R 
+--R
+--R   (288)  0.5367999050 547 E -36
+--R                                                                  Type: Float
+--E 288
+
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
